@@ -2,14 +2,15 @@ use super::event_driven_manager::EventDrivenManager;
 use super::time_driven_manager::TimeDrivenManager;
 use super::{WorkItem, CAP_WORK_QUEUE};
 use crate::basics::{EvalConfig, ExecutionMode::*, OutputHandler, Time};
+use crate::coordination::dynamic_schedule::DynamicSchedule;
 use crate::coordination::{EventEvaluation, TimeEvaluation};
 use crate::evaluator::{Evaluator, EvaluatorData};
 use crossbeam_channel::{bounded, unbounded};
-use rtlola_frontend::mir::{Deadline, OutputReference, RtLolaMir, Task};
+use rtlola_frontend::mir::RtLolaMir;
 use std::error::Error;
-use std::sync::Arc;
+use std::sync::{Arc, Condvar, Mutex};
 use std::thread;
-use std::time::{Duration, Instant};
+use std::time::Instant;
 
 pub(crate) struct Controller {
     ir: RtLolaMir,
@@ -18,12 +19,16 @@ pub(crate) struct Controller {
 
     /// Handles all kind of output behavior according to config.
     pub(crate) output_handler: Arc<OutputHandler>,
+
+    /// Dynamic schedules handles dynamic deadlines; The condition is notified whenever the schedule changes
+    dyn_schedule: Arc<(Mutex<DynamicSchedule>, Condvar)>,
 }
 
 impl Controller {
     pub(crate) fn new(ir: RtLolaMir, config: EvalConfig) -> Self {
         let output_handler = Arc::new(OutputHandler::new(&config, ir.triggers.len()));
-        Self { ir, config, output_handler }
+        let dyn_schedule = Arc::new((Mutex::new(DynamicSchedule::new()), Condvar::new()));
+        Self { ir, config, output_handler, dyn_schedule }
     }
 
     pub(crate) fn start(self) -> Result<Arc<OutputHandler>, Box<dyn Error>> {
@@ -31,7 +36,7 @@ impl Controller {
         match self.config.mode {
             Offline => self.evaluate_offline().map(|_| self.output_handler),
             Online => self.evaluate_online().map(|_| self.output_handler),
-            API => unreachable!(),
+            Api => unreachable!(),
         }
     }
 
@@ -40,16 +45,15 @@ impl Controller {
     fn evaluate_online(&self) -> Result<(), Box<dyn Error>> {
         let (work_tx, work_rx) = unbounded();
         let now = Instant::now();
-
         let copy_output_handler = self.output_handler.clone();
 
-        let has_time_driven = !self.ir.time_driven.is_empty();
-        if has_time_driven {
+        if self.ir.has_time_driven_features() {
             let work_tx_clone = work_tx.clone();
             let ir_clone = self.ir.clone();
+            let ds_clone = self.dyn_schedule.clone();
             let _ = thread::Builder::new().name("TimeDrivenManager".into()).spawn(move || {
-                let time_manager =
-                    TimeDrivenManager::setup(ir_clone, copy_output_handler).unwrap_or_else(|s| panic!("{}", s));
+                let time_manager = TimeDrivenManager::setup(ir_clone, copy_output_handler, ds_clone)
+                    .unwrap_or_else(|s| panic!("{}", s));
                 time_manager.start_online(now, work_tx_clone);
             });
         };
@@ -65,7 +69,13 @@ impl Controller {
         });
 
         let copy_output_handler = self.output_handler.clone();
-        let evaluatordata = EvaluatorData::new(self.ir.clone(), self.config.clone(), copy_output_handler, Some(now));
+        let evaluatordata = EvaluatorData::new(
+            self.ir.clone(),
+            self.config.clone(),
+            copy_output_handler,
+            Some(now),
+            self.dyn_schedule.clone(),
+        );
 
         let mut evaluator = evaluatordata.into_evaluator();
 
@@ -77,7 +87,7 @@ impl Controller {
             self.output_handler.debug(|| format!("Received {:?}.", item));
             match item {
                 WorkItem::Event(e, ts) => self.evaluate_event_item(&mut evaluator, &e, ts),
-                WorkItem::Time(t, ts) => self.evaluate_timed_item(&mut evaluator, &t, ts),
+                WorkItem::Time(t, ts) => self.evaluate_timed_item(&mut evaluator, t, ts),
                 WorkItem::End => {
                     self.output_handler.output(|| "Finished entire input. Terminating.");
                     std::process::exit(0);
@@ -93,8 +103,8 @@ impl Controller {
         let (work_tx, work_rx) = bounded(CAP_WORK_QUEUE);
         let (time_tx, time_rx) = bounded(1);
 
+        // Setup EventDrivenManager
         let output_copy_handler = self.output_handler.clone();
-
         let ir_clone = self.ir.clone();
         let cfg_clone = self.config.clone();
         let edm_thread = thread::Builder::new()
@@ -107,32 +117,29 @@ impl Controller {
             })
             .unwrap_or_else(|e| unreachable!("Failed to start EventDrivenManager thread: {}", e));
 
+        // Get start time
         let start_time = match time_rx.recv() {
             Err(e) => unreachable!("Did not receive a start event in offline mode! {}", e),
             Ok(ts) => ts,
         };
-
         let mut start_time_ref = self.output_handler.start_time.lock().unwrap();
         *start_time_ref = start_time;
         drop(start_time_ref);
 
-        let has_time_driven = !self.ir.time_driven.is_empty();
+        // Setup TimeDrivenManager
         let ir_clone = self.ir.clone();
         let output_copy_handler = self.output_handler.clone();
-        let time_manager = TimeDrivenManager::setup(ir_clone, output_copy_handler)?;
-        let mut due_streams = if has_time_driven {
-            // timed streams at time 0
-            time_manager.get_last_due()
-        } else {
-            vec![]
-        };
-        let mut next_deadline = Duration::default();
-        let mut deadline_cycle = time_manager.get_deadline_cycle();
+        let mut time_manager = TimeDrivenManager::setup(ir_clone, output_copy_handler, self.dyn_schedule.clone())?;
 
+        // Setup Evaluator
         let output_copy_handler = self.output_handler.clone();
-        let evaluatordata =
-            EvaluatorData::new(self.ir.clone(), self.config.clone(), output_copy_handler, Some(Instant::now()));
-
+        let evaluatordata = EvaluatorData::new(
+            self.ir.clone(),
+            self.config.clone(),
+            output_copy_handler,
+            Some(Instant::now()),
+            self.dyn_schedule.clone(),
+        );
         let mut evaluator = evaluatordata.into_evaluator();
 
         let mut current_time = Time::default();
@@ -142,30 +149,14 @@ impl Controller {
                 self.output_handler.debug(|| format!("Received {:?}.", item));
                 match item {
                     WorkItem::Event(e, ts) => {
-                        while has_time_driven && ts > next_deadline {
-                            // Go back in time, evaluate,...
-                            due_streams = self.schedule_timed(
-                                &mut evaluator,
-                                &mut deadline_cycle,
-                                &due_streams,
-                                &mut next_deadline,
-                            );
-                        }
+                        time_manager.accept_time_offline(&mut evaluator, ts);
                         self.output_handler.debug(|| format!("Schedule Event {:?}.", (&e, ts)));
                         self.evaluate_event_item(&mut evaluator, &e, ts);
                         current_time = ts;
                     }
                     WorkItem::Time(_, _) => panic!("Received time command in offline mode."),
                     WorkItem::End => {
-                        while has_time_driven && current_time == next_deadline {
-                            // schedule last timed event before terminating
-                            due_streams = self.schedule_timed(
-                                &mut evaluator,
-                                &mut deadline_cycle,
-                                &due_streams,
-                                &mut next_deadline,
-                            );
-                        }
+                        time_manager.end_offline(&mut evaluator, current_time);
                         self.output_handler.output(|| "Finished entire input. Terminating.");
                         self.output_handler.terminate();
                         break 'outer;
@@ -178,37 +169,15 @@ impl Controller {
         Ok(())
     }
 
-    fn schedule_timed<'a>(
-        &'a self,
-        evaluator: &mut Evaluator,
-        mut deadline_iter: impl Iterator<Item = &'a Deadline>,
-        due_streams: &Vec<OutputReference>,
-        next_deadline: &mut Time,
-    ) -> Vec<OutputReference> {
-        self.output_handler.debug(|| format!("Schedule Timed-Event {:?}.", (due_streams, *next_deadline)));
-        self.evaluate_timed_item(evaluator, due_streams, *next_deadline);
-        let deadline = deadline_iter.next().unwrap();
-        assert!(deadline.pause > Duration::from_secs(0));
-        *next_deadline += deadline.pause;
-        deadline
-            .due
-            .iter()
-            .map(|t| match t {
-                Task::Evaluate(idx) => *idx,
-                Task::Spawn(_idx) => unimplemented!("Periodic Spawns are not yet implemented!"),
-            })
-            .collect()
-    }
-
     #[inline]
-    pub(crate) fn evaluate_timed_item(&self, evaluator: &mut Evaluator, t: &TimeEvaluation, ts: Time) {
+    pub(crate) fn evaluate_timed_item(&self, evaluator: &mut Evaluator, t: TimeEvaluation, ts: Time) {
         self.output_handler.new_event();
-        evaluator.eval_time_driven_outputs(t.as_slice(), ts);
+        evaluator.eval_time_driven_tasks(t, ts);
     }
 
     #[inline]
     pub(crate) fn evaluate_event_item(&self, evaluator: &mut Evaluator, e: &EventEvaluation, ts: Time) {
         self.output_handler.new_event();
-        evaluator.eval_event(e.as_slice(), ts)
+        evaluator.eval_event(e, ts)
     }
 }
