@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import json
+import time
 from pathlib import Path
 from junit_xml import TestSuite, TestCase
 import subprocess
@@ -58,8 +59,50 @@ def print_trigger_too_many(message, expected, actual):
     sys.stdout.write('"' + message.strip() + '\"\x1b[1;31m' + " : {} ({} expected)".format(actual, expected) + '\x1b[0m\n')
 
 
-parser = argparse.ArgumentParser(description='Run end-to-end tests for rtlola-interpreter')
+def run_offline():
+    res = subprocess.run([rtlola_interpreter_executable_path_string, "monitor", "--offline", "--stdout", "--verbosity", "outputs", str(spec_file), "--csv-in", str(input_file)] + config, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, cwd=str(repo_base_dir), universal_newlines=True, timeout=10)
+    return res.returncode, iter(res.stdout.split("\n"))
 
+def run_online():
+    with open(str(input_file), "r") as csv:
+        input_lines = [line.strip() for line in csv.readlines()]
+    time_idx = input_lines[0].split(',').index("time")
+
+    out_file = open("temp_test_output.txt", "w+")
+    monitor = subprocess.Popen([rtlola_interpreter_executable_path_string, "monitor", "--online", "--stdout", "--verbosity", "outputs", str(spec_file)] + config, stdout=out_file, stderr=subprocess.STDOUT, cwd=str(repo_base_dir), stdin=subprocess.PIPE, universal_newlines=True)
+
+    # write csv header
+    monitor.stdin.write(input_lines[0]+os.linesep)
+
+    # write first event
+    last_event_time = float(input_lines[1].split(',')[time_idx])
+    monitor.stdin.write(input_lines[1]+os.linesep)
+    monitor.stdin.flush()
+
+    for line in input_lines[2:]:
+        cur_time = float(line.split(',')[time_idx])
+        due_time = cur_time - last_event_time
+        last_event_time = cur_time
+        time.sleep(due_time)
+        monitor.stdin.write(line+os.linesep)
+        monitor.stdin.flush()
+
+    monitor.stdin.close()
+    monitor.wait(timeout=10)
+    out_file.close()
+    with open("temp_test_output.txt", "r") as f:
+        lines = f.readlines()
+    out_file.close()
+    os.remove("temp_test_output.txt")
+    return monitor.returncode, iter(lines)
+
+parser = argparse.ArgumentParser(description='Run end-to-end tests for rtlola-interpreter')
+parser.add_argument("--online", action='store_true', help="Additionally runs all tests in online mode.", dest="online")
+args = parser.parse_args()
+if args.online:
+    run_mode = "online"
+else:
+    run_mode = "offline"
 
 running_on_windows = platform.system() == "Windows"
 executable_name = "rtlola-interpreter.exe" if running_on_windows else "rtlola-interpreter"
@@ -93,46 +136,56 @@ tests_passed = 0
 
 test_dir = repo_base_dir/"tests"
 tests = [test_file for test_file in test_dir.iterdir() if test_file.is_file() and test_file.suffix == ".rtlola_interpreter_test"]
-if len(sys.argv) == 2:
-    tests = [test_file for test_file in tests if sys.argv[1] in test_file.name]
 
 tests_passed = []
 tests_crashed = []
 tests_wrong_out = []
 return_code = 0
+
 with open("e2e-results.xml", 'w') as results_file:
     testcases = []
     for (mode, config) in [('closure', []), ('time-info', ["--time-info-rep", "absolute"])]:
         check_time_info = "--time-info-rep" in config
         for test_file in tests:
-            total_number_of_tests += 1
-            print("========================================================================")
-            test_name = "{} @ {}".format(mode, test_file.name.split('.')[0])
-            print_bold("{}:".format(test_name))
-            timed_out = False
-            err_out = []
             with test_file.open() as fd:
                 test_json = json.load(fd)
                 spec_file = build_path(repo_base_dir, test_json["spec_file"].split('/')[1:])
                 input_file = build_path(repo_base_dir, test_json["input_file"].split('/')[1:])
+
                 input_mode = "CSV"
                 if "input_mode" in test_json:
                     input_mode = test_json["input_mode"]
+
+                if input_mode != "PCAP" and run_mode not in test_json["modes"]:
+                    continue
+
+                total_number_of_tests += 1
+                print("========================================================================")
+                test_name = "{} @ {}".format(mode, test_file.name.split('.')[0])
+                print_bold("{}:".format(test_name))
+                timed_out = False
+                err_out = []
+
                 something_wrong = False
-                run_result = None
+                returncode = None
                 try:
                     if input_mode == "PCAP":
                         run_result = subprocess.run([rtlola_interpreter_executable_path_string, "ids", "--stdout", "--verbosity", "outputs", str(spec_file), "192.168.178.0/24", "--pcap-in", str(input_file)] + config, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=str(repo_base_dir), universal_newlines=True, timeout=10)
-                    else:
-                        run_result = subprocess.run([rtlola_interpreter_executable_path_string, "monitor", "--offline", "--stdout", "--verbosity", "outputs", str(spec_file), "--csv-in", str(input_file)] + config, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=str(repo_base_dir), universal_newlines=True, timeout=10)
+                        returncode = run_result.returncode
+                        lines = iter(run_result.stdout.split("\n"))
+                    elif run_mode == "offline":
+                        (returncode, lines) = run_offline()
+                    elif run_mode == "online":
+                        (returncode, lines) = run_online()
+
                 except subprocess.TimeoutExpired:
                     tests_crashed.append(test_name)
                     print_fail("Test timed out")
                     something_wrong = True
                     timed_out = True
-                if run_result is not None:
-                    if run_result.returncode == 0:
-                        lines = iter(run_result.stdout.split("\n"))
+
+                if returncode is not None:
+                    if returncode == 0:
                         triggers_in_output = dict()
 
                         # count triggers
@@ -167,7 +220,8 @@ with open("e2e-results.xml", 'w') as results_file:
                                     print_trigger(trigger, expected_count, actual_count)
                                     err_out.append("trigger \"{}\":  : {} ({} expected)".format(trigger,actual_count, expected_count))
                                     something_wrong = True
-                                elif check_time_info and actual_time_info != expected_time_info:
+                                elif run_mode == "offline" and check_time_info and actual_time_info != expected_time_info:
+                                    # only check time in offline mode
                                     print_fail("time info for trigger \"{}\" incorrect:".format(trigger))
                                     err_out.append("time info for trigger \"{}\" incorrect:".format(trigger))
                                     print_info("got | wanted")
